==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/af/general.php <==
<?php

    return [
    'accessories'			=> 'bykomstighede',
    'activated'			    => 'geaktiveer',
    'accessory'				=> 'Bykomstigheid',
    'accessory_report'		=> 'Toebehoreverslag',
    'action'                => 'aksie',
    'activity_report'		=> 'Aktiwiteitsverslag',
    'address'				=> 'adres',
    'admin'					=> 'admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Bykomende sitplekke',
    'all_assets'			=> 'Alle bates',
    'all'       			=> 'Almal',
    'archived'              => 'argief',
    'asset_models'			=> 'Bate Modelle',
    'asset_model'			=> 'model',
    'asset'					=> 'bate',
    'asset_report'          => 'Asset Report',
    'asset_tag'				=> 'Bate-tag',
    'assets_available'		=> 'bates beskikbaar',
    'audit'				    => 'oudit',
    'audit_report'			=> 'Ouditlogboek',
    'assets'				=> 'bates',
    'avatar_delete'         => 'Verwyder Avatar',
    'avatar_upload'         => 'Laai avatar op',
    'back'      			=> 'terug',
    'bad_data'      		=> 'Niks gevind. Miskien slegte data?',
    'bulkaudit'             => 'Grootmaat Oudit',
    'bulkaudit_status'      => 'Ouditstatus',
    'bulk_checkout'  		=> 'Grootmaat Checkout',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'kanselleer',
    'categories'			=> 'kategorieë',
    'category'				=> 'kategorie',
    'change' 		        => 'In uit',
    'changeemail'  			=> 'Verander e-pos adres',
    'changepassword'  		=> 'Verander wagwoord',
    'checkin'  				=> 'Inboek',
    'checkin_from'  		=> 'Kontroleer vanaf',
    'checkout'  			=> 'Uitteken',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Requests',
    'city'  				=> 'Stad',
	'click_here'			=> 'Klik hier',
    'clear_selection'		=> 'Clear Selection',
    'companies'			    => 'maatskappye',
    'company'				=> 'maatskappy',
    'component'			    => 'komponent',
    'components'			=> 'komponente',
	'complete'				=> 'volledige',
    'consumable'			=> 'verbruikbare',
    'consumables'			=> 'Consumables',
    'country'  				=> 'land',
    'create'				=> 'Skep nuwe',
    'created'               => 'Item geskep',
    'created_asset'			=> 'geskep bate',
    'created_at' 			=> 'Geskep op',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Opgedateer op',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Huidige',
    'custom_report'         => 'Aangepaste bateverslag',
    'dashboard'				=> 'Dashboard',
    'days'      			=> 'dae',
    'days_to_next_audit'    => 'Dae na Volgende Oudit',
    'date'					=> 'datum',
    'debug_warning'         => 'Waarskuwing!',
    'debug_warning_text'    => 'Hierdie program word uitgevoer in die produksiemodus met debugging aangeskakel. Dit kan sensitiewe data blootstel indien u aansoek vir die buitewêreld toeganklik is. Deaktiveer debug-modus deur die <code>APP_DEBUG</code>-waarde in jou <code>.env</code>-lêer te stel na <code>false</code>.',
    'delete'  				=> 'verwyder',
    'delete_confirm'  		=> 'Are you sure you wish to delete :item?',
    'deleted'  				=> 'geskrap',
    'delete_seats'  		=> 'Plekke verwyder',
    'departments'           => 'departemente',
    'department'           => 'Departement',
    'deployed'				=> 'ontplooi',
    'depreciation_report'	=> 'Waardeverminderingsverslag',
    'details'               => 'Details',
    'download'				=> 'Aflaai',
    'download_all'				=> 'Download All',
    'depreciation'			=> 'waardevermindering',
    'editprofile'  			=> 'Wysig jou profiel',
    'eol'					=> 'EOL',
    'email_domain'			=> 'E-pos Domein',
    'email_format'			=> 'E-pos formaat',
    'email_domain_help'		=> 'Dit word gebruik om e-posadresse te genereer wanneer u dit invoer',
    'filastname_format'			=> 'Eerste Voorletter (jsmith@voorbeeld.com)',
    'firstname_lastname_format'	=> 'Vir Naam Van (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'First Name Last Name (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Last Name First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'eerste',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Eerste naam',
    'first_name_format'		=> 'Voornaam (jane@example.com)',
    'files'                 => 'Files',
    'file_name'				=> 'lêer',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Lêeroplaaie',
    'generate'				=> 'genereer',
     'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'groepe',
    'gravatar_email'        => 'Gravatar e-pos adres',
    'history'  			    => 'Geskiedenis',
    'history_for'  			=> 'Geskiedenis vir',
    'id'  					=> 'ID',
    'image'                 => 'Image',
    'image_delete'         	=> 'Vee prent uit',
    'image_upload'         	=> 'Laai prent op',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'invoer',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Invoer Geskiedenis',
    'asset_maintenance'        => 'Bate Onderhoud',
    'asset_maintenance_report' => 'Asset Maintenance Report',
    'asset_maintenances'       => 'Asset Maintenances',
    'item'  				=> 'item',
    'insufficient_permissions' => 'Onvoldoende toestemmings!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Taal',
    'last'					=> 'laaste',
    'last_login'            => 'Laaste Aanmelding',
    'last_name'             => 'Van',
    'license'				=> 'lisensie',
    'license_report'        => 'Lisensie Verslag',
    'licenses_available'	=> 'lisensies beskikbaar',
    'licenses'				=> 'lisensies',
    'list_all'				=> 'Lys almal',
    'loading'				=> 'laai',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Hierdie funksie is afgeskakel vir die demo-installasie.',
    'location'              => 'plek',
    'locations'				=> 'plekke',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Teken uit',
    'lookup_by_tag'     => 'Opsoek deur Asset Tag',
    'maintenances'          => 'Maintenances',
    'manufacturer'			=> 'vervaardiger',
    'manufacturers'			=> 'vervaardigers',
    'markdown'				=> 'Hierdie veld laat <a href="https://help.github.com/articles/github-flavored-markdown/">Gitub-gegeurde markdown</a> toe.',
    'min_amt'				=> 'Min. HOEV',
    'min_amt_help'	=> 'Minimum aantal items wat beskikbaar moet wees voordat \'n waarskuwing geaktiveer word.',
    'model_no'				=> 'Model Nr.',
    'months'				=> 'maande',
    'moreinfo'				=> 'Meer inligting',
    'name'					=> 'naam',
    'next'					=> 'volgende',
    'next_audit_date'		=> 'Volgende ouditdatum',
    'last_audit'		    => 'Laaste Oudit',
    'new'					=> 'nuwe!',
    'no_depreciation'		=> 'Geen Waardevermindering',
    'no_results'			=> 'Geen resultate.',
    'no'  					=> 'Geen',
    'notes'  				=> 'notas',
    'order_number'          => 'Bestellingnommer',
    'page_menu'				=> 'Wys _MENU_ items',
    'pagination_info'		=> 'Wys _START_ tot _END_ van _TOTAL_ items',
    'pending'				=> 'hangende',
    'people'				=> 'mense',
    'per_page'				=> 'Resultate per bladsy',
    'previous'				=> 'vorige',
    'processing'			=> 'verwerking',
    'profile'				=> 'Jou profiel',
    'purchase_cost'                              => 'Aankoopskoste',
    'purchase_date'         => 'Aankoop datum',
    'qty'		            => 'HOEV',
    'quantity'		        => 'hoeveelheid',
    'ready_to_deploy'		=> 'Klaar om te implementeer',
    'recent_activity'		=> 'Onlangse aktiwiteite',
    'remove_company'        => 'Verwyder Maatskappyvereniging',
    'reports'				=> 'Berigte',
    'restored'				=> 'restored',
    'requested'				=> 'versoek',
    'request_canceled'      => 'Versoek gekanselleer',
    'save'  				=> 'Save',
    'select'				=> 'Kies',
    'search'				=> 'Soek',
    'select_category'       => 'Kies \'n kategorie',
    'select_department'       => 'Kies \'n Departement',
    'select_depreciation'	=> 'Kies \'n waardeverminderingstipe',
    'select_location'		=> 'Kies \'n plek',
    'select_manufacturer'	=> 'Kies \'n vervaardiger',
    'select_model'			=> 'Kies \'n model',
    'select_supplier'		=> 'Kies \'n Verskaffer',
    'select_user'			=> 'Kies \'n gebruiker',
    'select_date'			=> 'Kies Datum (JJJJ-MM-DD)',
    'select_statuslabel'	=> 'Kies Status',
    'select_company'    	=> 'Kies Maatskappy',
    'select_asset'    		=> 'Kies Asset',
    'settings'				=> 'instellings',
    'show_deleted'  		=> 'Show Deleted',
    'show_current'  		=> 'Show Current',
    'sign_in'				=> 'Teken in',
    'signature'             => 'Handtekening',
    'skin'       			=> 'Skin',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MODE: Sommige funksies is afgeskakel vir hierdie installasie.',
    'site_name'				=> 'Site Naam',
    'state'  				=> 'staat',
    'status_labels'			=> 'Status etikette',
    'status'    			=> 'status',
    'supplier'              => 'verskaffer',
    'suppliers'  			=> 'Verskaffers',
    'sure_to_delete'    => 'Is jy seker jy wil verwyder',
    'submit'				=> 'Indien',
    'target'                => 'teiken',
    'time_and_date_display' => 'Tyd en datum vertoon',
    'total_assets'			=> 'totale bates',
    'total_licenses'		=> 'totale lisensies',
    'total_accessories'		=> 'totale toebehore',
    'total_consumables'		=> 'totale verbruiksgoedere',
    'type'  				=> 'tipe',
    'undeployable'			=> 'Un-verbintenis',
    'unknown_admin'			=> 'Onbekende Admin',
    'username_format'		=> 'Gebruikernaam',
    'update'                => 'Opdateer',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'opgelaai',
    'user'					=> 'gebruiker',
    'accepted'			    => 'aanvaarde',
    'declined'			    => 'afgeneem',
    'unaccepted_asset_report' => 'Onaanvaarde Bates',
    'users'                 => 'gebruikers',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Bekyk Toegewysde Bates',
    'website'               => 'webwerf',
    'welcome'				=> 'Welkom, naam',
    'years'					=> 'jaar',
    'yes' 					=> 'Ja',
    'zip'  					=> 'zip',
    'noimage'				=> 'Geen prent opgelaai of prent nie gevind nie.',
    'token_expired'         => 'Jou vormsessie het verval. Probeer asseblief weer.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    ];

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/af/general.php <==
<?php

    return [
    'accessories'			=> 'bykomstighede',
    'activated'			    => 'geaktiveer',
    'accessory'				=> 'Bykomstigheid',
    'accessory_report'		=> 'Toebehoreverslag',
    'action'                => 'aksie',
    'activity_report'		=> 'Aktiwiteitsverslag',
    'address'				=> 'adres',
    'admin'					=> 'admin',
    'administrator'			=> 'Administrator',
    'add_seats'             => 'Bykomende sitplekke',
    'all_assets'			=> 'Alle bates',
    'all'       			=> 'Almal',
    'archived'              => 'argief',
    'asset_models'			=> 'Bate Modelle',
    'asset_model'			=> 'model',
    'asset'					=> 'bate',
    'asset_report'          => 'Asset Report',
    'asset_tag'				=> 'Bate-tag',
    'asset_tags'            => 'Asset Tags',
    'assets_available'		=> 'Assets available',
    'accept_assets'         => 'Accept Assets :name',
    'accept_assets_menu'    => 'Accept Assets',
    'audit'				    => 'oudit',
    'audit_report'			=> 'Ouditlogboek',
    'assets'				=> 'bates',
    'avatar_delete'         => 'Verwyder Avatar',
    'avatar_upload'         => 'Laai avatar op',
    'back'      			=> 'terug',
    'bad_data'      		=> 'Niks gevind. Miskien slegte data?',
    'bulkaudit'             => 'Grootmaat Oudit',
    'bulkaudit_status'      => 'Ouditstatus',
    'bulk_checkout'  		=> 'Grootmaat Checkout',
    'bulk_edit'             => 'Bulk Edit',
    'bulk_delete'           => 'Bulk Delete',
    'bulk_actions'          => 'Bulk Actions',
    'bulk_checkin_delete'   => 'Bulk Checkin &amp; Delete',
    'bystatus'              => 'by Status',
    'cancel'  				=> 'kanselleer',
    'categories'			=> 'kategorieë',
    'category'				=> 'kategorie',
    'change' 		        => 'In uit',
    'changeemail'  			=> 'Verander e-pos adres',
    'changepassword'  		=> 'Verander wagwoord',
    'checkin'  				=> 'Inboek',
    'checkin_from'  		=> 'Kontroleer vanaf',
    'checkout'  			=> 'Uitteken',
    'checkouts_count'       => 'Checkouts',
    'checkins_count'        => 'Checkins',
    'user_requests_count'   => 'Requests',
    'city'  				=> 'Stad',
    'click_here'			=> 'Klik hier',
    'clear_selection'		=> 'Clear Selection',
    'companies'			    => 'maatskappye',
    'company'				=> 'maatskappy',
    'component'			    => 'komponent',
    'components'			=> 'komponente',
    'complete'				=> 'volledige',
    'consumable'			=> 'verbruikbare',
    'consumables'			=> 'Consumables',
    'country'  				=> 'land',
    'create'				=> 'Skep nuwe',
    'created'               => 'Item geskep',
    'created_asset'			=> 'geskep bate',
    'created_at' 			=> 'Geskep op',
    'record_created' 		=> 'Record Created',
    'updated_at' 			=> 'Opgedateer op',
    'currency'  			=> '$', // this is deprecated
    'current'  				=> 'Huidige',
    'current_password'      => 'Current Password',
    'customize_report'      => 'Customize Report',
    'custom_report'         => 'Aangepaste bateverslag',
    'dashboard'				=> 'Dashboard',
    'days'      			=> 'dae',
    'days_to_next_audit'    => 'Dae na Volgende Oudit',
    'date'					=> 'datum',
    'debug_warning'         => 'Waarskuwing!',
    'debug_warning_text'    => 'Hierdie program word uitgevoer in die produksiemodus met debugging aangeskakel. Dit kan sensitiewe data blootstel indien u aansoek vir die buitewêreld toeganklik is. Deaktiveer debug-modus deur die <code>APP_DEBUG</code>-waarde in jou <code>.env</code>-lêer te stel na <code>false</code>.',
    'delete'  				=> 'verwyder',
    'delete_confirm'  		=> 'Are you sure you wish to delete :item?',
    'deleted'  				=> 'geskrap',
    'delete_seats'  		=> 'Plekke verwyder',
    'deletion_failed'       => 'Deletion failed',
    'departments'           => 'departemente',
    'department'            => 'Departement',
    'deployed'				=> 'ontplooi',
    'depreciation'			=> 'waardevermindering',
    'depreciations'         => 'Depreciations',
    'depreciation_report'	=> 'Waardeverminderingsverslag',
    'details'               => 'Details',
    'download'				=> 'Aflaai',
    'download_all'		    => 'Download All',
    'editprofile'  			=> 'Wysig jou profiel',
    'eol'					=> 'EOL',
    'email_domain'			=> 'E-pos Domein',
    'email_format'			=> 'E-pos formaat',
    'employee_number'       => 'Employee Number',
    'email_domain_help'		=> 'Dit word gebruik om e-posadresse te genereer wanneer u dit invoer',
    'error'				    => 'Error',
    'filastname_format'			=> 'Eerste Voorletter (jsmith@voorbeeld.com)',
    'firstname_lastname_format'	=> 'Vir Naam Van (jane.smith@example.com)',
    'firstname_lastname_underscore_format' => 'First Name Last Name (jane_smith@example.com)',
    'lastnamefirstinitial_format' =>  'Last Name First Initial (smithj@example.com)',
    'firstintial_dot_lastname_format' => 'First Initial Last Name (j.smith@example.com)',
    'first'					=> 'eerste',
    'firstnamelastname'     => 'First Name Last Name (janesmith@example.com)',
    'lastname_firstinitial' => 'Last Name First Initial (smith_j@example.com)',
    'firstinitial.lastname' => 'First Initial Last Name (j.smith@example.com)',
    'firstnamelastinitial'  => 'First Name Last Initial (janes@example.com)',
    'first_name'			=> 'Eerste naam',
    'first_name_format'		=> 'Voornaam (jane@example.com)',
    'files'                 => 'Files',
    'file_name'				=> 'lêer',
    'file_type'             => 'File Type',
    'file_uploads'			=> 'Lêeroplaaie',
    'file_upload'           => 'File Upload',
    'generate'				=> 'genereer',
    'generate_labels'       => 'Generate Labels',
    'github_markdown'      => 'This field accepts <a href="https://help.github.com/articles/github-flavored-markdown/">Github flavored markdown</a>.',
    'groups'				=> 'groepe',
    'gravatar_email'        => 'Gravatar e-pos adres',
    'gravatar_url'          => '<a href="http://gravatar.com"><small>Change your avatar at Gravatar.com</small></a>.',
    'history'  			    => 'Geskiedenis',
    'history_for'  			=> 'Geskiedenis vir',
    'id'  					=> 'ID',
    'image'                 => 'Image',
    'image_delete'         	=> 'Vee prent uit',
    'image_upload'         	=> 'Laai prent op',
    'filetypes_accepted_help'    => 'Accepted filetype is :types. Max upload size allowed is :size.|Accepted filetypes are :types. Max upload size allowed is :size.',
    'filetypes_size_help'   => 'Max upload size allowed is :size.',
    'image_filetypes_help'  => 'Accepted filetypes are jpg, webp, png, gif, and svg. Max upload size allowed is :size.',
    'import'         	    => 'invoer',
    'importing'         	=> 'Importing',
    'importing_help'        => 'You can import assets, accessories, licenses, components, consumables, and users via CSV file. <br><br>The CSV should be comma-delimited and formatted with headers that match the ones in the <a href="https://snipe-it.readme.io/docs/importing" target="_new">sample CSVs in the documentation</a>.',
    'import-history'        => 'Invoer Geskiedenis',
    'asset_maintenance'        => 'Bate Onderhoud',
    'asset_maintenance_report' => 'Asset Maintenance Report',
    'asset_maintenances'       => 'Asset Maintenances',
    'item'  				=> 'item',
    'item_name'             => 'Item Name',
    'insufficient_permissions' => 'Onvoldoende toestemmings!',
    'kits'       			=> 'Predefined Kits',
    'language'				=> 'Taal',
    'last'					=> 'laaste',
    'last_login'            => 'Laaste Aanmelding',
    'last_name'             => 'Van',
    'license'				=> 'lisensie',
    'license_report'        => 'Lisensie Verslag',
    'licenses_available'	=> 'lisensies beskikbaar',
    'licenses'				=> 'lisensies',
    'list_all'				=> 'Lys almal',
    'loading'				=> 'Loading... please wait....',
    'lock_passwords'        => 'This field value will not be saved in a demo installation.',
    'feature_disabled'      => 'Hierdie funksie is afgeskakel vir die demo-installasie.',
    'location'              => 'plek',
    'locations'				=> 'plekke',
    'logo_size'				=> 'Square logos look best with Logo + Text. Logo maximum display size is 50px high x 500px wide.  ',
    'logout'				=> 'Teken uit',
    'lookup_by_tag'     => 'Opsoek deur Asset Tag',
    'maintenances'          => 'Maintenances',
    'manage_api_keys'       => 'Manage API Keys',
    'manufacturer'			=> 'vervaardiger',
    'manufacturers'			=> 'vervaardigers',
    'markdown'				=> 'Hierdie veld laat <a href="https://help.github.com/articles/github-flavored-markdown/">Gitub-gegeurde markdown</a> toe.',
    'min_amt'				=> 'Min. HOEV',
    'min_amt_help'          => 'Minimum number of items that should be available before an alert gets triggered. Leave Min. QTY blank if you do not want to receive alerts for low inventory.',
    'model_no'				=> 'Model Nr.',
    'months'				=> 'maande',
    'moreinfo'				=> 'Meer inligting',
    'name'					=> 'naam',
    'new_password'          => 'New Password',
    'next'					=> 'volgende',
    'next_audit_date'		=> 'Volgende ouditdatum',
    'last_audit'		    => 'Laaste Oudit',
    'new'					=> 'nuwe!',
    'no_depreciation'		=> 'Geen Waardevermindering',
    'no_results'			=> 'Geen resultate.',
    'no'  					=> 'Geen',
    'notes'  				=> 'notas',
    'order_number'          => 'Bestellingnommer',
    'page_menu'				=> 'Wys _MENU_ items',
    'pagination_info'		=> 'Wys _START_ tot _END_ van _TOTAL_ items',
    'pending'				=> 'hangende',
    'people'				=> 'mense',
    'per_page'				=> 'Resultate per bladsy',
    'previous'				=> 'vorige',
    'processing'			=> 'verwerking',
    'profile'				=> 'Jou profiel',
    'purchase_cost'                              => 'Aankoopskoste',
    'purchase_date'         => 'Aankoop datum',
    'qty'		            => 'HOEV',
    'quantity'		        => 'hoeveelheid',
    'quantity_minimum'      => 'You have :count items below or almost below minimum quantity levels',
    'quickscan_checkin'  	=> 'Quick Scan Checkin',
    'quickscan_checkin_status'  	=> 'Checkin Status',
    'ready_to_deploy'		=> 'Klaar om te implementeer',
    'recent_activity'		=> 'Onlangse aktiwiteite',
    'remaining'             => 'Remaining',
    'remove_company'        => 'Verwyder Maatskappyvereniging',
    'reports'				=> 'Berigte',
    'restored'				=> 'restored',
    'restore'				=> 'Restore',
    'requestable_models'    => 'Requestable Models',
    'requested'				=> 'versoek',
    'requested_date'        => 'Requested Date',
    'requested_assets'      => 'Requested Assets',
    'requested_assets_menu' => 'Requested Assets',
    'request_canceled'      => 'Versoek gekanselleer',
    'save'  				=> 'Save',
    'select'				=> 'Kies',
    'select_all'            => 'Select All',
    'search'				=> 'Soek',
    'select_category'       => 'Kies \'n kategorie',
    'select_department'     => 'Kies \'n Departement',
    'select_depreciation'	=> 'Kies \'n waardeverminderingstipe',
    'select_location'		=> 'Kies \'n plek',
    'select_manufacturer'	=> 'Kies \'n vervaardiger',
    'select_model'			=> 'Kies \'n model',
    'select_supplier'		=> 'Kies \'n Verskaffer',
    'select_user'			=> 'Kies \'n gebruiker',
    'select_date'			=> 'Kies Datum (JJJJ-MM-DD)',
    'select_statuslabel'	=> 'Kies Status',
    'select_company'    	=> 'Kies Maatskappy',
    'select_asset'    		=> 'Kies Asset',
    'settings'				=> 'instellings',
    'show_deleted'  		=> 'Show Deleted',
    'show_current'  		=> 'Show Current',
    'sign_in'				=> 'Teken in',
    'signature'             => 'Handtekening',
    'skin'       			=> 'Skin',
    'slack_msg_note'        => 'A slack message will be sent',
    'slack_test_msg'        => 'Oh hai! Looks like your Slack integration with Snipe-IT is working!',
    'some_features_disabled' => 'DEMO MODE: Sommige funksies is afgeskakel vir hierdie installasie.',
    'site_name'				=> 'Site Naam',
    'state'  				=> 'staat',
    'status_labels'			=> 'Status etikette',
    'status'    			=> 'status',
    'supplier'              => 'verskaffer',
    'suppliers'  			=> 'Verskaffers',
    'sure_to_delete'    => 'Is jy seker jy wil verwyder',
    'submit'				=> 'Indien',
    'target'                => 'teiken',
    'toggle_navigation'     => 'Toogle Navigation',
    'time_and_date_display' => 'Tyd en datum vertoon',
    'total_assets'			=> 'totale bates',
    'total_licenses'		=> 'totale lisensies',
    'total_accessories'		=> 'totale toebehore',
    'total_consumables'		=> 'totale verbruiksgoedere',
    'type'  				=> 'tipe',
    'undeployable'			=> 'Un-verbintenis',
    'unknown_admin'			=> 'Onbekende Admin',
    'username_format'		=> 'Gebruikernaam',
    'update'                => 'Opdateer',
    'upload_filetypes_help'      => 'Allowed filetypes are png, gif, jpg, jpeg, doc, docx, pdf, xls, xlsx, txt, lic, xml, zip, rtf and rar. Max upload size allowed is :size.',
    'uploaded'              => 'opgelaai',
    'user'					=> 'gebruiker',
    'accepted'			    => 'aanvaarde',
    'declined'			    => 'afgeneem',
    'unaccepted_asset_report' => 'Onaanvaarde Bates',
    'users'                 => 'gebruikers',
    'viewall'				=> 'View All',
    'viewassets'  			=> 'Bekyk Toegewysde Bates',
    'viewassetsfor'         => 'View Assets for :name',
    'website'               => 'webwerf',
    'welcome'				=> 'Welkom, naam',
    'years'					=> 'jaar',
    'yes' 					=> 'Ja',
    'zip'  					=> 'zip',
    'noimage'				=> 'Geen prent opgelaai of prent nie gevind nie.',
    'token_expired'         => 'Jou vormsessie het verval. Probeer asseblief weer.',
    'login_enabled'         => 'Login Enabled',
    'audit_due'             => 'Due for Audit',
    'audit_overdue'         => 'Overdue for Audit',
    'accept'                => 'Accept :asset',
    'i_accept'              => 'I accept',
    'i_decline'             => 'I decline',
    'accept_decline'        => 'Accept/Decline',
    'sign_tos'              => 'Sign below to indicate that you agree to the terms of service:',
    'clear_signature'       => 'Clear Signature',
    'show_help'             => 'Show help',
    'hide_help'             => 'Hide help',
    'view_all'              => 'view all',
    'hide_deleted'          => 'Hide Deleted',
    'email'                 => 'Email',
    'do_not_change'         => 'Do Not Change',
    'bug_report'            => 'Report a Bug',
    'user_manual'           => 'User\'s Manual',
    'setup_step_1'          => 'Step 1',
    'setup_step_2'          => 'Step 2',
    'setup_step_3'          => 'Step 3',
    'setup_step_4'          => 'Step 4',
    'setup_config_check'    => 'Configuration Check',
    'setup_create_database' => 'Create Database Tables',
    'setup_create_admin'    => 'Create Admin User',
    'setup_done'            => 'Finished!',
    'bulk_edit_about_to'    => 'You are about to edit the following: ',
    'checked_out'           => 'Checked Out',
    'checked_out_to'        => 'Checked out to',
    'fields'                => 'Fields',
    'last_checkout'         => 'Last Checkout',
    'due_to_checkin'        => 'The following :count items are due to be checked in soon:',
    'expected_checkin'      => 'Expected Checkin',
    'reminder_checked_out_items' => 'This is a reminder of the items currently checked out to you. If you feel this list is inaccurate (something is missing, or something appears here that you believe you never received), please email :reply_to_name at :reply_to_address.',
    'changed'               => 'Changed',
    'to'                    => 'To',
    'report_fields_info'    => '<p>Select the fields you would like to include in your custom report, and click Generate. The file (custom-asset-report-YYYY-mm-dd.csv) will download automatically, and you can open it in Excel.</p>
            <p>If you would like to export only certain assets, use the options below to fine-tune your results.</p>',
    'range'                 => 'Range',
    'bom_remark'            => 'Add a BOM (byte-order mark) to this CSV',
    'improvements'          => 'Improvements',
    'information'           => 'Information',
    'permissions'           => 'Permissions',
    'managed_ldap'          => '(Managed via LDAP)',
    'export'                => 'Export',
    'ldap_sync'             => 'LDAP Sync',
    'ldap_user_sync'        => 'LDAP User Sync',
    'synchronize'           => 'Synchronize',
    'sync_results'          => 'Synchronization Results',
    'license_serial'        => 'Serial/Product Key',
    'invalid_category'      => 'Invalid category',
    'dashboard_info'        => 'This is your dashboard. There are many like it, but this one is yours.',
    '60_percent_warning'    => '60% Complete (warning)',
    'dashboard_empty'       => 'It looks like you haven not added anything yet, so we do not have anything awesome to display. Get started by adding some assets, accessories, consumables, or licenses now!',
    'new_asset'             => 'New Asset',
    'new_license'           => 'New License',
    'new_accessory'         => 'New Accessory',
    'new_consumable'        => 'New Consumable',
    'collapse'              => 'Collapse',
    'assigned'              => 'Assigned',
    'asset_count'           => 'Asset Count',
    'accessories_count'     => 'Accessories Count',
    'consumables_count'     => 'Consumables Count',
    'components_count'      => 'Components Count',
    'licenses_count'        => 'Licenses Count',
    'notification_error'    => 'Error:',
    'notification_error_hint' => 'Please check the form below for errors',
    'notification_success'  => 'Success:',
    'notification_warning'   => 'Warning:',
    'notification_info'      => 'Info:',
    'asset_information'     => 'Asset Information',
    'model_name'            => 'Model Name:',
    'asset_name'            => 'Asset Name:',
    'consumable_information' => 'Consumable Information:',
    'consumable_name'       => 'Consumable Name:',
    'accessory_information' => 'Accessory Information:',
    'accessory_name'       => 'Accessory Name:',
    'clone_item'            => 'Clone Item',
    'checkout_tooltip' => 'Check this item out',
    'checkin_tooltip' => 'Check this item in',
    'checkout_user_tooltip' => 'Check this item out to a user',
];
